/*

Copyright (c) 2006. Adobe Systems Incorporated.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice,
    this list of conditions and the following disclaimer.
  * Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
  * Neither the name of Adobe Systems Incorporated nor the names of its
    contributors may be used to endorse or promote products derived from this
    software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

@ignore
modified 2009-04-09 14:59 : Jean-Pierre
modified 2011-05-05 14:49 : riverapj
*/
package com.adobe.cairngorm.business
{
   import com.adobe.cairngorm.CairngormError;
   import com.adobe.cairngorm.CairngormMessageCodes;
   
   import flash.utils.Dictionary;
   
   import mx.rpc.remoting.RemoteObject;
   
   /**
    * Used to manage all RemoteObject's defined on the IServiceLocator instance.
    */
   internal class RemoteObjects extends AbstractServices
   {
      private var services : Dictionary = new Dictionary();

      /**
       * Constructor
       */
      function RemoteObjects()
      {

      }

      /**
       * Register the services.
       * @param serviceLocator the IServiceLocator instance.
       */
      public override function register( serviceLocator : IServiceLocator ) : void
      {
         var accessors : XMLList = getAccessors( serviceLocator );
         
         for ( var i : uint = 0; i < accessors.length(); i++ )
         {
            var name : String = accessors[ i ];
            var obj : Object = serviceLocator[ name ];
            
            if ( obj is RemoteObject )
            {
               RemoteObject( obj ).requestTimeout = timeout;
               services[ name ] = obj;
            }
         }
      }
      
      /**
       * Return the service with the given name.
       * @param name the name of the service.
       * @return the service.
       */
      public override function getService( name : String ) : Object
      {
         var service : RemoteObject = services[ name ];
         
         if ( service == null )
         {
            throw new CairngormError(
               CairngormMessageCodes.REMOTE_OBJECT_NOT_FOUND, name );
         }
         
         return service;
      }
      
      /**
       * Set the credentials for all registered services.
       * @param username the username to set.
       * @param password the password to set.
       */
      public override function setCredentials( username : String, password : String ) : void
      {
         for ( var name : String in services )
         {
            var service : RemoteObject = services[ name ];
            service.setCredentials( username, password );
         }
      }
      
      /**
       * Set the remote credentials for all registered services.
       * @param username the username to set.
       * @param password the password to set.
       */
      public override function setRemoteCredentials( username : String, password : String ) : void
      {
         for ( var name : String in services )
         {
            var service : RemoteObject = services[ name ];
            
            service.setRemoteCredentials( username, password );
         }
      }
      
      /**
       * Release the resources held by the service.
       */
      public override function release() : void
      {
         // do nothing.
      }
      
      /**
       * Log the user out of all registered services.
       */
      public override function logout() : void
      {
         for ( var name : String in services )
         {
            var service : RemoteObject = services[ name ];
            
            serviceLogout( service );
         }
      }
      
      protected override function serviceLogout( service : Object   ) : void
      {
         var remoteService : RemoteObject = RemoteObject( service );
         
         if ( remoteService.channelSet.authenticated )
         {
            remoteService.logout();
         }
      }
      
        /* Dynamic remote objects registration */
        
      /**
       * Register a new remote object as module
       * @param name the module name to set.
       * @param object the remote object.
       */
      public function registerRemoteObject(name : String, object : RemoteObject) : void 
      {
          if (services[ name ] == null) 
          {
              services[ name ] = object;
          }
          else
          {
               throw new CairngormError(
               CairngormMessageCodes.SERVICE_ID_ALREADY_REGISTERED, name );
          }
      }

      /**
       * Unregister a remote object
       * @param name the module name to unregister.
       */
      public function unRegisterRemoteObject(name : String) : void
      {
          if (services[ name ] != null)
          {
              delete services[ name ];
          }
          else
          {
               throw new CairngormError(
               CairngormMessageCodes.SERVICE_ID_NOT_REGISTERED, name );
          }
      }
      
      
   }
}